[coreboot-gerrit] Change in coreboot[master]: samsung/lumpy: change HDA codec SSID to fix Windows

Matt DeVillier (Code Review) gerrit at coreboot.org
Fri Jul 7 05:30:07 CEST 2017


Matt DeVillier has uploaded this change for review. ( https://review.coreboot.org/20485


Change subject: samsung/lumpy: change HDA codec SSID to fix Windows
......................................................................

samsung/lumpy: change HDA codec SSID to fix Windows

With the existing SSID, the driver loaded by Windows results
in the headphone jack and internal mic being non-functional.
With the new SSID, the a functional driver is loaded and
everything works correctly.  Linux works correctly with
either SSID so the change has no impact there.

New SSID extracted from Windows drivers (.inf).

Change-Id: I4195d00d6b18dcd0039747d9883cdf8e1a76f461
Signed-off-by: Matt DeVillier <matt.devillier at gmail.com>
---
M src/mainboard/samsung/lumpy/hda_verb.c
1 file changed, 3 insertions(+), 3 deletions(-)



  git pull ssh://review.coreboot.org:29418/coreboot refs/changes/85/20485/1

diff --git a/src/mainboard/samsung/lumpy/hda_verb.c b/src/mainboard/samsung/lumpy/hda_verb.c
index 9c97f12..252d872 100644
--- a/src/mainboard/samsung/lumpy/hda_verb.c
+++ b/src/mainboard/samsung/lumpy/hda_verb.c
@@ -18,11 +18,11 @@
 const u32 cim_verb_data[] = {
 	/* coreboot specific header */
 	0x10134210,	// Codec Vendor / Device ID: Cirrus Logic CS4210
-	0x144db082,	// Subsystem ID
+	0x152D0924,	// Subsystem ID
 	0x00000007,	// Number of jacks
 
-	/* NID 0x01, HDA Codec Subsystem ID Verb Table: 0x144db082 */
-	AZALIA_SUBVENDOR(0x0, 0x144db082),
+	/* NID 0x01, HDA Codec Subsystem ID Verb Table: 0x152D0924 */
+	AZALIA_SUBVENDOR(0x0, 0x152D0924),
 
 	0x00170500,
 

-- 
To view, visit https://review.coreboot.org/20485
To unsubscribe, visit https://review.coreboot.org/settings

Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: I4195d00d6b18dcd0039747d9883cdf8e1a76f461
Gerrit-Change-Number: 20485
Gerrit-PatchSet: 1
Gerrit-Owner: Matt DeVillier <matt.devillier at gmail.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://mail.coreboot.org/pipermail/coreboot-gerrit/attachments/20170707/9dbfc870/attachment.html>


More information about the coreboot-gerrit mailing list